@@ -321,9 +321,7 @@ def PySconsSetup(env=None, args=ARGUMENTS, tools=['default', PYTOOL()]):
         W = SCons.Node.Walker(env.Entry(t))
         while not W.is_done():
             N = W.get_next()
-            try:
-                if N.exists(): files.add(N)
-            except: pass
+            files.add(N)
 
     env.Command(out, list(files) + [os.path.join(basename, ".sconsign.dblite")], "tar cjf $TARGET $SOURCES")
 
